@@ -15,7 +15,7 @@ use Archive::Libarchive::EntryLinkResolver;
 use parent qw( Exporter );
 
 # ABSTRACT: Modern Perl bindings to libarchive
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 
 my $ffi = Archive::Libarchive::Lib->ffi;
@@ -87,7 +87,7 @@ Archive::Libarchive - Modern Perl bindings to libarchive
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -131,6 +131,25 @@ when used as a universal archiver/extractor.  Supported formats include:
 
 =back
 
+There are a number of "simple" interfaces around this distribution, which are worth considering if you do not need
+the full power and configurability that this distribution provides.
+
+=over 4
+
+=item L<Archive::Libarchive::Peek>
+
+Provides an interface for listing and retrieving entries from an archive without extracting them to the local filesystem.
+
+=item L<Archive::Libarchive::Extract>
+
+Provides an interface for extracting arbitrary archives of any format/filter supported by C<libarchive>.
+
+=item L<Archive::Libarchive::Unwrap>
+
+Decompresses / unwraps files that have been compressed or wrapped in any of the filter formats supported by C<libarchive>
+
+=back
+
 This distribution is split up into several classes, that correspond to C<libarchive> classes.  Probably the best
 place to start when learning how to use this module is to look at the L</EXAMPLES> section below, but you
 can also take a look at the main class documentation for the operation that you are interested in as well:
@@ -268,7 +287,7 @@ These examples are translated from the C<libarchive> C examples, which can be fo
 
 =over 4
 
-=item L<https://github.com/libarchive/libarchive/wiki/Examples#List_contents_of_Archive_stored_in_File>
+=item L<https://github.com/libarchive/libarchive/wiki/Examples>
 
 =back
 
@@ -340,6 +359,9 @@ Note that the call to L<read_data_skip|Archive::Libarchive::API/read_data_skip>
 L<Archive::Libarchive> will invoke it automatically if you request the next header without reading the data for the
 last entry.
 
+The module L<Archive::Libarchive::Peek> also provides similar functionality to this example in a simple, less
+powerful interface.
+
 =head2 List contents of archive stored in memory
 
 There are several variants of the open methods.  The "filename" variant used above is intended to be simple
@@ -380,7 +402,7 @@ callbacks.
  use Archive::Libarchive qw( :const );
  
  my $r = Archive::Libarchive::ArchiveRead->new;
- $r->support_compression_all;
+ $r->support_filter_all;
  $r->support_format_all;
  
  my $fh;
@@ -427,7 +449,7 @@ output of a libarchive filter chain, including files with multiple encodings, su
  use Archive::Libarchive;
  
  my $r = Archive::Libarchive::ArchiveRead->new;
- $r->support_compression_all;
+ $r->support_filter_all;
  $r->support_format_raw;
  $r->open_filename("hello.txt.uu");
  $r->next_header(Archive::Libarchive::Entry->new);
@@ -445,6 +467,9 @@ Also note that the "raw" format handler does not recognize or accept empty files
 able to read empty files, you'll need to also invoke the
 L<support_format_empty method on Archive::Libarchive::ArchiveRead|Archive::Libarchive::API/support_format_empty>.
 
+The module L<Archive::Libarchive::Unwrap> also provides similar functionality to this example in a simple, less
+powerful interface.
+
 =head2 A basic write example
 
 The following is a very simple example of using L<Archive::Libarchive> to write a group of files into a tar archive.
@@ -583,7 +608,7 @@ L<Archive::Libarchive::ArchiveRead> instance to an L<Archive::Libarchive::DiskWr
  
  my $r = Archive::Libarchive::ArchiveRead->new;
  $r->support_format_all;
- $r->support_compression_all;
+ $r->support_filter_all;
  
  my $dw = Archive::Libarchive::DiskWrite->new;
  $dw->disk_set_options(
@@ -618,10 +643,11 @@ L<Archive::Libarchive::ArchiveRead> instance to an L<Archive::Libarchive::DiskWr
    if($e->size > 0)
    {
      my $buffer;
+     my $offset;
      while(1) {
  
-       $ret = $r->read_data(\$buffer);
-       last if $ret == 0;
+       $ret = $r->read_data_block(\$buffer, \$offset);
+       last if $ret == ARCHIVE_EOF;
        if($ret < ARCHIVE_OK) {
          if($ret < ARCHIVE_WARN) {
            die "file read error on member @{[ $e->pathname ]} @{[ $r->error_string ]}";
@@ -630,7 +656,7 @@ L<Archive::Libarchive::ArchiveRead> instance to an L<Archive::Libarchive::DiskWr
          }
        }
  
-       $ret = $dw->write_data(\$buffer);
+       $ret = $dw->write_data_block(\$buffer, $offset);
        if($ret < ARCHIVE_OK) {
          if($ret < ARCHIVE_WARN) {
            die "file write error on member @{[ $e->pathname ]} @{[ $dw->error_string ]}";
@@ -657,6 +683,9 @@ L<Archive::Libarchive::ArchiveRead> instance to an L<Archive::Libarchive::DiskWr
 You could create an archive by going the other way by copying entries from an
 L<Archive::Libarchive::DiskRead> instance to an L<Archive::Libarchive::ArchiveWrite> instance.
 
+The module L<Archive::Libarchive::Extract> also provides similar functionality to this example in a simple, less
+powerful interface.
+
 =head1 CONSTANTS
 
 This module provides all of the constants used by C<libarchive>.  These typically
@@ -789,6 +818,18 @@ ensure that the code generation is done consistently.
 
 =over 4
 
+=item L<Archive::Libarchive::Peek>
+
+Provides an interface for listing and retrieving entries from an archive without extracting them to the local filesystem.
+
+=item L<Archive::Libarchive::Extract>
+
+Provides an interface for extracting arbitrary archives of any format/filter supported by C<libarchive>.
+
+=item L<Archive::Libarchive::Unwrap>
+
+Decompresses / unwraps files that have been compressed or wrapped in any of the filter formats supported by C<libarchive>
+
 =item L<Archive::Libarchive::API>
 
 This contains the full and complete API for all of the L<Archive::Libarchive>
