@@ -4,18 +4,19 @@ use strict;
 use warnings;
 use 5.020;
 use Archive::Libarchive::Lib;
-use FFI::Platypus::Buffer qw( scalar_to_buffer scalar_to_pointer );
+use FFI::Platypus::Buffer qw( scalar_to_buffer scalar_to_pointer grow set_used_length window );
 use FFI::Platypus::Memory qw( strdup free );
 use Ref::Util qw( is_plain_scalarref is_plain_coderef is_blessed_ref is_plain_arrayref );
 use Carp ();
-use PeekPoke::FFI ();
 use experimental qw( signatures );
 use parent qw( Archive::Libarchive::Archive );
+use constant;
 
 # ABSTRACT: Libarchive read archive class
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 my $ffi = Archive::Libarchive::Lib->ffi;
+constant->import(_opaque_size => $ffi->sizeof('opaque'));
 
 
 $ffi->mangler(sub ($name) { "archive_read_$name"  });
@@ -69,8 +70,7 @@ $ffi->attach( [ open1 => 'open' ] => [ 'archive_read'] => 'int' => sub {
         $self->{read_buffer} = undef;
         my $size = $sub->($r, \$self->{read_buffer});
         my $ptr = defined $self->{read_buffer} ? scalar_to_pointer($self->{read_buffer}) : undef;
-        my $pp = PeekPoke::FFI->new( type => 'opaque', base => $ptrptr );
-        $pp->poke(0, $ptr);
+        _memcpy($ptrptr, [$ptr], _opaque_size());
         return $size;
       });
     }
@@ -143,19 +143,21 @@ $ffi->attach( [data => 'read_data'] => ['archive_read', 'opaque', 'size_t'] => '
   my($xsub, $self, $ref, $size) = @_;
   $size ||= 512;
 
-  # TODO: this is highly non-performant!
-  $$ref = "\0" x $size;
+  grow $$ref, $size, { clear => 0 };
   my $rsize = $xsub->($self, (scalar_to_buffer $$ref));
-
-  $$ref = substr $$ref, 0, $rsize if $size != $rsize;
+  set_used_length $$ref, $rsize;
 
   return $rsize;
 });
 
-# TODO:
-$ffi->attach( [data_block   => '_read_data_block'  ] => ['archive_read', 'opaque*', 'size_t*', 'sint64*'] => 'int' );
-$ffi->attach( [data_into_fd => '_read_data_into_fd'] => ['archive_read', 'int'] => 'int' );
 
+$ffi->attach( [data_block => 'read_data_block' ] => ['archive_read', 'opaque*', 'size_t*', 'sint64*'] => 'int' => sub {
+  my $xsub = shift;
+  my($ptr, $size);
+  my $ret = $xsub->($_[0], \$ptr, \$size, $_[2]);
+  window ${$_[1]}, $ptr, $size if defined $ptr;
+  return $ret;
+});
 
 
 $ffi->attach( append_filter => ['archive_read', 'archive_filter_t'] => 'int' );
@@ -196,7 +198,7 @@ Archive::Libarchive::ArchiveRead - Libarchive read archive class
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -348,6 +350,20 @@ C<$buffer>.  Up to C<$size> bytes will be read.  This will return the number of
 read on success, zero (C<0>) on EOF and a L<normal status code|Archive::Libarchive/CONSTANTS>
 on error.
 
+=head2 read_data_block
+
+ # archive_read_data_block
+ my $int = $r->read_data_block(\$buffer, \$offset);
+
+A zero-copy version of archive_read_data that also exposes the file offset
+of each returned block.  Note that the client has no way to specify
+the desired size of the block.  The API does guarantee that offsets will
+be strictly increasing and that returned blocks will not overlap.
+
+Gotcha with this method is that it returns C<ARCHIVE_EOF> when there is no
+more data to read instead of the number of bytes.  The size can be determined
+from the length of the newly resized C<$buffer>.
+
 =head2 append_filter
 
  # archive_read_append_filter
@@ -383,6 +399,18 @@ file with encrypted entries.
 
 =over 4
 
+=item L<Archive::Libarchive::Peek>
+
+Provides an interface for listing and retrieving entries from an archive without extracting them to the local filesystem.
+
+=item L<Archive::Libarchive::Extract>
+
+Provides an interface for extracting arbitrary archives of any format/filter supported by C<libarchive>.
+
+=item L<Archive::Libarchive::Unwrap>
+
+Decompresses / unwraps files that have been compressed or wrapped in any of the filter formats supported by C<libarchive>
+
 =item L<Archive::Libarchive>
 
 This is the main top-level module for using C<libarchive> from
