@@ -4,11 +4,12 @@ use strict;
 use warnings;
 use 5.020;
 use Archive::Libarchive::Lib;
+use FFI::Platypus::Buffer qw( scalar_to_buffer );
 use experimental qw( signatures );
 use parent qw( Archive::Libarchive::ArchiveWrite );
 
 # ABSTRACT: Libarchive disk write class
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 my $ffi = Archive::Libarchive::Lib->ffi;
 
@@ -24,6 +25,12 @@ $ffi->attach( [ disk_new => 'new' ] => [] => 'opaque' => sub {
 require Archive::Libarchive::Lib::DiskWrite unless $Archive::Libarchive::no_gen;
 
 
+$ffi->attach( [data_block => 'write_data_block'] => ['archive_write', 'opaque', 'size_t', 'sint64'] => 'ssize_t' => sub {
+  my $xsub = shift;
+  my($ptr, $size) = scalar_to_buffer ${$_[1]};
+  $xsub->($_[0], $ptr, $size, $_[2]);
+});
+
 1;
 
 __END__
@@ -38,7 +45,7 @@ Archive::Libarchive::DiskWrite - Libarchive disk write class
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -79,10 +86,29 @@ Create a new disk write object.
 This is a subset of total list of methods available to all archive classes.
 For the full list see L<Archive::Libarchive::API/Archive::Libarchive::ArchiveRead>.
 
+=head2 write_data_block
+
+ # archive_write_data_block
+ my $ssize_t = $dw->write_data_block(\$buffer, $offset);
+
+Write the entry content data to the disk.  This is intended to be used with L<Archive::Libarchive::ArchiveRead/read_data_block>.
+
 =head1 SEE ALSO
 
 =over 4
 
+=item L<Archive::Libarchive::Peek>
+
+Provides an interface for listing and retrieving entries from an archive without extracting them to the local filesystem.
+
+=item L<Archive::Libarchive::Extract>
+
+Provides an interface for extracting arbitrary archives of any format/filter supported by C<libarchive>.
+
+=item L<Archive::Libarchive::Unwrap>
+
+Decompresses / unwraps files that have been compressed or wrapped in any of the filter formats supported by C<libarchive>
+
 =item L<Archive::Libarchive>
 
 This is the main top-level module for using C<libarchive> from
