@@ -9,7 +9,7 @@ use FFI::ExtractSymbols;
 use Path::Tiny qw( path );
 use Clang::CastXML;
 use Const::Introspect::C;
-use YAML qw( Dump );
+#use YAML qw( Dump );
 use List::Util 1.33 qw( all sum0 );
 use PerlX::Maybe;
 use Template;
@@ -221,8 +221,8 @@ sub process_functions ($href, $global, $bindings)
       $type->{target_type} = $target_type;
     }
 
-    say "unhandled type:";
-    say Dump({ $name => $type });
+    #say "unhandled type:";
+    #say Dump({ $name => $type });
     return undef;
   };
 
@@ -263,9 +263,6 @@ sub process_functions ($href, $global, $bindings)
       # we use the newer next_header2 method
       push @prune, $name if $name eq 'archive_read_next_header';
 
-      # This was renamed to archive_write_openfile
-      push @prune, $name if $name eq 'archive_write_open_file';
-
       # This ... doesn't really work or make sense for Perl the
       # way it is implemented.
       push @prune, $name if $name eq 'archive_write_open_memory';
@@ -279,7 +276,7 @@ sub process_functions ($href, $global, $bindings)
       push @prune, $name if $name eq 'archive_free';
 
       # these are aliases that are being renamed in 3.x and removed in 4.x
-      push @prune, $name if $name =~ /^archive_(write_set_compression.*|position_(compressed|uncompressed)|compression(_name|))$/;
+      push @prune, $name if $name =~ /^archive_(write_set_compression.*|read_support_compression.*|position_(compressed|uncompressed)|compression(_name|)|(read|write)_open_file|entry_acl_text(|_w))$/;
 
       # The _finish forms were renamed to _Free in 3.x and will be
       # removed in 4.x
@@ -395,6 +392,8 @@ sub process_functions ($href, $global, $bindings)
     my $incomplete = (defined $ret_type && all { defined $_ } @arg_types) ? undef : 1;
     $count{$incomplete ? 'incomplete' : 'generated'}++;
 
+    say "warning: $orig is incomplete" if $incomplete;
+
     push $bindings->{$class}->@*, {
             symbol_name => $orig,
       maybe optional    => $opt,
